@@ -1,6 +1,6 @@
 #!/usr/bin/env python
-__version__='0.3.0'
-last_update='2022-11-16'
+__version__='0.3.1'
+last_update='2022-12-06'
 author='Damien Marsic, damien.marsic@aliyun.com'
 
 import sys,os,gzip,time,math
@@ -23,7 +23,7 @@ def aln2seq(fn,type,full,ref):
     fail=''
     seq={}
     if ref:
-        ref,fail=getfasta(ref,aa,aa,False)
+        ref,fail=getfasta(ref,type,type,False)
         if fail:
             return seq,fail
         ref=list(ref.values())[0]
@@ -210,7 +210,7 @@ def csv_read(fname,dic,header):
             z=intorfloat(x[i][j])
             if z==y[j]:
                 continue
-            if not y[j] or z=='other' or z=='float' and y[j]=='int':
+            if not y[j] or z=='other' or (z=='float' and y[j]=='int'):
                 y[j]=z
     for n in ('int','float'):
         q=int
@@ -619,3 +619,4 @@ def transl(seq):
     x=''.join([gcode.get(seq[3*i:3*i+3],'X') for i in range(len(seq)//3)])
     return x
 
+
